Crate sokobanlib

Crate sokobanlib 

Structs

CheckErrors
Type contains all check errors.
Level
Level in game. Name is optional name - can be empty. Width and height determines dimensions of the level. An area is fields of level ordered from top to bottom and from left to right.
LevelParseError
Level parse errors - contains errors and level name
LevelSet
Level set. Contains levels and name of the level set.
LevelState
LevelState is state game in given a level. A level state contains changed an area of a level after moves. Initially an area is copied from level.
TermGame
The game in terminal mode. Structure contains level state and some terminal utilities.
TermLevelSet
The levelset game in terminal mode.

Enums

CheckError
Check level error.
Direction
Type represents direction of the move.
Field
Type represents field in level area.
GameResult
Possible game result.
ParseError
Error caused while parsing or creating level.
XmlParseError
Parse error concerned XML structure.

Type Aliases

LevelResult
Level result - contains level or parse error.